@@ -8,15 +8,15 @@ from wagtail.wagtailadmin.menu import MenuItem
 from . import views
 
 
+@hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
         url(r'^styleguide/$', views.index, name='wagtailstyleguide'),
     ]
-hooks.register('register_admin_urls', register_admin_urls)
 
 
+@hooks.register('construct_main_menu')
 def construct_main_menu(request, menu_items):
     menu_items.append(
         MenuItem(_('Styleguide'), urlresolvers.reverse('wagtailstyleguide'), classnames='icon icon-image', order=1000)
     )
-hooks.register('construct_main_menu', construct_main_menu)
