@@ -1,8 +1,14 @@
 from django.db import models
 from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
+from django.contrib.auth.models import AbstractBaseUser, PermissionsMixin, BaseUserManager
 from django.utils.encoding import python_2_unicode_compatible
+from django.conf.urls import url
+from django.http import HttpResponse
+
+from taggit.models import TaggedItemBase
 
 from modelcluster.fields import ParentalKey
+from modelcluster.tags import ClusterTaggableManager
 
 from wagtail.wagtailcore.models import Page, Orderable
 from wagtail.wagtailcore.fields import RichTextField
@@ -12,6 +18,7 @@ from wagtail.wagtaildocs.edit_handlers import DocumentChooserPanel
 from wagtail.wagtailforms.models import AbstractEmailForm, AbstractFormField
 from wagtail.wagtailsnippets.models import register_snippet
 from wagtail.wagtailsearch import indexed
+from wagtail.contrib.wagtailroutablepage.models import RoutablePage
 
 
 EVENT_AUDIENCE_CHOICES = (
@@ -28,6 +35,50 @@ COMMON_PANELS = (
 )
 
 
+class CustomUserManager(BaseUserManager):
+    def _create_user(self, username, email, password,
+                     is_staff, is_superuser, **extra_fields):
+        """
+        Creates and saves a User with the given username, email and password.
+        """
+        if not username:
+            raise ValueError('The given username must be set')
+        email = self.normalize_email(email)
+        user = self.model(username=username, email=email,
+                          is_staff=is_staff, is_active=True,
+                          is_superuser=is_superuser, **extra_fields)
+        user.set_password(password)
+        user.save(using=self._db)
+        return user
+
+    def create_user(self, username, email=None, password=None, **extra_fields):
+        return self._create_user(username, email, password, False, False,
+                                 **extra_fields)
+
+    def create_superuser(self, username, email, password, **extra_fields):
+        return self._create_user(username, email, password, True, True,
+                                 **extra_fields)
+
+
+class CustomUser(AbstractBaseUser, PermissionsMixin):
+    username = models.CharField(max_length=100, unique=True)
+    email = models.EmailField(max_length=255, blank=True)
+    is_staff = models.BooleanField(default=True)
+    is_active = models.BooleanField(default=True)
+    first_name = models.CharField(max_length=50, blank=True)
+    last_name = models.CharField(max_length=50, blank=True)
+
+    USERNAME_FIELD = 'username'
+
+    objects = CustomUserManager()
+
+    def get_full_name(self):
+        return self.first_name + ' ' + self.last_name
+
+    def get_short_name(self):
+        return self.first_name
+
+
 # Link fields
 
 class LinkFields(models.Model):
@@ -274,9 +325,11 @@ FormPage.content_panels = [
 ]
 
 
-# Snippets
 
 # Snippets
+class AdvertPlacement(models.Model):
+    page = ParentalKey('wagtailcore.Page', related_name='advert_placements')
+    advert = models.ForeignKey('tests.Advert', related_name='+')
 
 @python_2_unicode_compatible
 class Advert(models.Model):
@@ -383,9 +436,39 @@ class SearchTestOldConfig(models.Model, indexed.Indexed):
         },
     }
 
+
 class SearchTestOldConfigList(models.Model, indexed.Indexed):
     """
     This tests that the Indexed class can correctly handle models that
     use the old "indexed_fields" configuration format using a list.
     """
     indexed_fields = ['title', 'content']
+
+
+def routable_page_external_view(request, arg):
+    return HttpResponse("EXTERNAL VIEW: " + arg)
+
+class RoutablePageTest(RoutablePage):
+    subpage_urls = (
+        url(r'^$', 'main', name='main'),
+        url(r'^archive/year/(\d+)/$', 'archive_by_year', name='archive_by_year'),
+        url(r'^archive/author/(?P<author_slug>.+)/$', 'archive_by_author', name='archive_by_author'),
+        url(r'^external/(.+)/$', routable_page_external_view, name='external_view')
+    )
+
+    def archive_by_year(self, request, year):
+        return HttpResponse("ARCHIVE BY YEAR: " + str(year))
+
+    def archive_by_author(self, request, author_slug):
+        return HttpResponse("ARCHIVE BY AUTHOR: " + author_slug)
+
+    def main(self, request):
+        return HttpResponse("MAIN VIEW")
+
+
+class TaggedPageTag(TaggedItemBase):
+    content_object = ParentalKey('tests.TaggedPage', related_name='tagged_items')
+
+
+class TaggedPage(Page):
+    tags = ClusterTaggableManager(through=TaggedPageTag, blank=True)
