@@ -3,14 +3,17 @@ from django.http import HttpResponse
 from wagtail.wagtailcore import hooks
 from wagtail.wagtailcore.whitelist import attribute_rule, check_url, allow_without_attributes
 
+
+# Register one hook using decorators...
+@hooks.register('insert_editor_css')
 def editor_css():
     return """<link rel="stylesheet" href="/path/to/my/custom.css">"""
-hooks.register('insert_editor_css', editor_css)
 
 
 def editor_js():
     return """<script src="/path/to/my/custom.js"></script>"""
 hooks.register('insert_editor_js', editor_js)
+# And the other using old-style function calls
 
 
 def whitelister_element_rules():
