@@ -1,3 +1,7 @@
+from __future__ import unicode_literals
+
+from six import text_type
+
 from django.utils.text import slugify
 from django.utils.html import format_html
 
@@ -7,10 +11,10 @@ class MenuItem(object):
         self.label = label
         self.url = url
         self.classnames = classnames
-        self.name = (name or slugify(unicode(label)))
+        self.name = (name or slugify(text_type(label)))
         self.order = order
 
     def render_html(self):
         return format_html(
-            u"""<li class="menu-{0}"><a href="{1}" class="{2}">{3}</a></li>""",
+            """<li class="menu-{0}"><a href="{1}" class="{2}">{3}</a></li>""",
             self.name, self.url, self.classnames, self.label)
