@@ -2,18 +2,30 @@ from datetime import timedelta
 
 from django.test import TestCase
 from django.core.urlresolvers import reverse
-from django.contrib.auth.models import User, Permission
+from django.contrib.auth import get_user_model
+from django.contrib.auth.models import Group, Permission
 from django.core import mail
 from django.core.paginator import Paginator
 from django.utils import timezone
 
-from wagtail.tests.models import SimplePage, EventPage, EventPageCarouselItem, StandardIndex, BusinessIndex, BusinessChild, BusinessSubIndex
+from wagtail.tests.models import SimplePage, EventPage, EventPageCarouselItem, StandardIndex, BusinessIndex, BusinessChild, BusinessSubIndex, TaggedPage
 from wagtail.tests.utils import unittest, WagtailTestUtils
 from wagtail.wagtailcore.models import Page, PageRevision
-from wagtail.wagtailcore.signals import page_published
+from wagtail.wagtailcore.signals import page_published, page_unpublished
 from wagtail.wagtailusers.models import UserProfile
 
 
+def submittable_timestamp(timestamp):
+    """
+    Helper function to translate a possibly-timezone-aware datetime into the format used in the
+    go_live_at / expire_at form fields - "YYYY-MM-DD hh:mm", with no timezone indicator.
+    This will be interpreted as being in the server's timezone (settings.TIME_ZONE), so we
+    need to pass it through timezone.localtime to ensure that the client and server are in
+    agreement about what the timestamp means.
+    """
+    return str(timezone.localtime(timestamp)).split('.')[0]
+
+
 class TestPageExplorer(TestCase, WagtailTestUtils):
     def setUp(self):
         # Find root page
@@ -180,8 +192,8 @@ class TestPageCreation(TestCase, WagtailTestUtils):
             'title': "New page!",
             'content': "Some content",
             'slug': 'hello-world',
-            'go_live_at': str(go_live_at).split('.')[0],
-            'expire_at': str(expire_at).split('.')[0],
+            'go_live_at': submittable_timestamp(go_live_at),
+            'expire_at': submittable_timestamp(expire_at),
         }
         response = self.client.post(reverse('wagtailadmin_pages_create', args=('tests', 'simplepage', self.root_page.id)), post_data)
 
@@ -203,8 +215,8 @@ class TestPageCreation(TestCase, WagtailTestUtils):
             'title': "New page!",
             'content': "Some content",
             'slug': 'hello-world',
-            'go_live_at': str(timezone.now() + timedelta(days=2)).split('.')[0],
-            'expire_at': str(timezone.now() + timedelta(days=1)).split('.')[0],
+            'go_live_at': submittable_timestamp(timezone.now() + timedelta(days=2)),
+            'expire_at': submittable_timestamp(timezone.now() + timedelta(days=1)),
         }
         response = self.client.post(reverse('wagtailadmin_pages_create', args=('tests', 'simplepage', self.root_page.id)), post_data)
 
@@ -219,7 +231,7 @@ class TestPageCreation(TestCase, WagtailTestUtils):
             'title': "New page!",
             'content': "Some content",
             'slug': 'hello-world',
-            'expire_at': str(timezone.now() + timedelta(days=-1)).split('.')[0],
+            'expire_at': submittable_timestamp(timezone.now() + timedelta(days=-1)),
         }
         response = self.client.post(reverse('wagtailadmin_pages_create', args=('tests', 'simplepage', self.root_page.id)), post_data)
 
@@ -268,8 +280,8 @@ class TestPageCreation(TestCase, WagtailTestUtils):
             'content': "Some content",
             'slug': 'hello-world',
             'action-publish': "Publish",
-            'go_live_at': str(go_live_at).split('.')[0],
-            'expire_at': str(expire_at).split('.')[0],
+            'go_live_at': submittable_timestamp(go_live_at),
+            'expire_at': submittable_timestamp(expire_at),
         }
         response = self.client.post(reverse('wagtailadmin_pages_create', args=('tests', 'simplepage', self.root_page.id)), post_data)
 
@@ -290,7 +302,7 @@ class TestPageCreation(TestCase, WagtailTestUtils):
 
     def test_create_simplepage_post_submit(self):
         # Create a moderator user for testing email
-        moderator = User.objects.create_superuser('moderator', 'moderator@email.com', 'password')
+        moderator = get_user_model().objects.create_superuser('moderator', 'moderator@email.com', 'password')
 
         # Submit
         post_data = {
@@ -428,14 +440,16 @@ class TestPageEdit(TestCase, WagtailTestUtils):
         self.assertTrue(child_page_new.has_unpublished_changes)
 
     def test_edit_post_scheduled(self):
-        go_live_at = timezone.now() + timedelta(days=1)
-        expire_at = timezone.now() + timedelta(days=2)
+        # put go_live_at and expire_at several days away from the current date, to avoid
+        # false matches in content_json__contains tests
+        go_live_at = timezone.now() + timedelta(days=10)
+        expire_at = timezone.now() + timedelta(days=20)
         post_data = {
             'title': "I've been edited!",
             'content': "Some content",
             'slug': 'hello-world',
-            'go_live_at': str(go_live_at).split('.')[0],
-            'expire_at': str(expire_at).split('.')[0],
+            'go_live_at': submittable_timestamp(go_live_at),
+            'expire_at': submittable_timestamp(expire_at),
         }
         response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.child_page.id, )), post_data)
 
@@ -459,8 +473,8 @@ class TestPageEdit(TestCase, WagtailTestUtils):
             'title': "I've been edited!",
             'content': "Some content",
             'slug': 'hello-world',
-            'go_live_at': str(timezone.now() + timedelta(days=2)).split('.')[0],
-            'expire_at': str(timezone.now() + timedelta(days=1)).split('.')[0],
+            'go_live_at': submittable_timestamp(timezone.now() + timedelta(days=2)),
+            'expire_at': submittable_timestamp(timezone.now() + timedelta(days=1)),
         }
         response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.child_page.id, )), post_data)
 
@@ -475,7 +489,7 @@ class TestPageEdit(TestCase, WagtailTestUtils):
             'title': "I've been edited!",
             'content': "Some content",
             'slug': 'hello-world',
-            'expire_at': str(timezone.now() + timedelta(days=-1)).split('.')[0],
+            'expire_at': submittable_timestamp(timezone.now() + timedelta(days=-1)),
         }
         response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.child_page.id, )), post_data)
 
@@ -525,8 +539,8 @@ class TestPageEdit(TestCase, WagtailTestUtils):
             'content': "Some content",
             'slug': 'hello-world',
             'action-publish': "Publish",
-            'go_live_at': str(go_live_at).split('.')[0],
-            'expire_at': str(expire_at).split('.')[0],
+            'go_live_at': submittable_timestamp(go_live_at),
+            'expire_at': submittable_timestamp(expire_at),
         }
         response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.child_page.id, )), post_data)
 
@@ -550,8 +564,8 @@ class TestPageEdit(TestCase, WagtailTestUtils):
             'content': "Some content",
             'slug': 'hello-world',
             'action-publish': "Publish",
-            'go_live_at': str(go_live_at).split('.')[0],
-            'expire_at': str(expire_at).split('.')[0],
+            'go_live_at': submittable_timestamp(go_live_at),
+            'expire_at': submittable_timestamp(expire_at),
         }
         response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.child_page.id, )), post_data)
 
@@ -590,7 +604,7 @@ class TestPageEdit(TestCase, WagtailTestUtils):
 
     def test_page_edit_post_submit(self):
         # Create a moderator user for testing email
-        moderator = User.objects.create_superuser('moderator', 'moderator@email.com', 'password')
+        moderator = get_user_model().objects.create_superuser('moderator', 'moderator@email.com', 'password')
 
         # Tests submitting from edit page
         post_data = {
@@ -796,6 +810,15 @@ class TestPageDelete(TestCase, WagtailTestUtils):
         self.assertEqual(response.status_code, 403)
 
     def test_page_delete_post(self):
+        # Connect a mock signal handler to page_unpublished signal
+        signal_fired = [False]
+        signal_page = [None]
+        def page_unpublished_handler(sender, instance, **kwargs):
+            signal_fired[0] = True
+            signal_page[0] = instance
+        page_unpublished.connect(page_unpublished_handler)
+
+        # Post
         post_data = {'hello': 'world'} # For some reason, this test doesn't work without a bit of POST data
         response = self.client.post(reverse('wagtailadmin_pages_delete', args=(self.child_page.id, )), post_data)
 
@@ -805,6 +828,38 @@ class TestPageDelete(TestCase, WagtailTestUtils):
         # Check that the page is gone
         self.assertEqual(Page.objects.filter(path__startswith=self.root_page.path, slug='hello-world').count(), 0)
 
+        # Check that the page_unpublished signal was fired
+        self.assertTrue(signal_fired[0])
+        self.assertEqual(signal_page[0], self.child_page)
+        self.assertEqual(signal_page[0], signal_page[0].specific)
+
+    def test_page_delete_notlive_post(self):
+        # Same as above, but this makes sure the page_unpublished signal is not fired
+        # when if the page is not live when it is deleted
+
+        # Unpublish the page
+        self.child_page.live = False
+        self.child_page.save()
+
+        # Connect a mock signal handler to page_unpublished signal
+        signal_fired = [False]
+        def page_unpublished_handler(sender, instance, **kwargs):
+            signal_fired[0] = True
+        page_unpublished.connect(page_unpublished_handler)
+
+        # Post
+        post_data = {'hello': 'world'} # For some reason, this test doesn't work without a bit of POST data
+        response = self.client.post(reverse('wagtailadmin_pages_delete', args=(self.child_page.id, )), post_data)
+
+        # Should be redirected to explorer page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Check that the page is gone
+        self.assertEqual(Page.objects.filter(path__startswith=self.root_page.path, slug='hello-world').count(), 0)
+
+        # Check that the page_unpublished signal was not fired
+        self.assertFalse(signal_fired[0])
+
 
 class TestPageSearch(TestCase, WagtailTestUtils):
     def setUp(self):
@@ -899,6 +954,260 @@ class TestPageMove(TestCase, WagtailTestUtils):
         self.assertEqual(response.status_code, 200)
 
 
+class TestPageCopy(TestCase, WagtailTestUtils):
+    def setUp(self):
+        # Find root page
+        self.root_page = Page.objects.get(id=2)
+
+        # Create a page
+        self.test_page = self.root_page.add_child(instance=SimplePage(
+            title="Hello world!",
+            slug='hello-world',
+            live=True,
+        ))
+
+        # Create a couple of child pages
+        self.test_child_page = self.test_page.add_child(instance=SimplePage(
+            title="Child page",
+            slug='child-page',
+            live=True,
+        ))
+
+        self.test_unpublished_child_page = self.test_page.add_child(instance=SimplePage(
+            title="Unpublished Child page",
+            slug='unpublished-child-page',
+            live=False,
+        ))
+
+        # Login
+        self.user = self.login()
+
+    def test_page_copy(self):
+        response = self.client.get(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )))
+
+        # Check response
+        self.assertEqual(response.status_code, 200)
+        self.assertTemplateUsed(response, 'wagtailadmin/pages/copy.html')
+
+        # Make sure all fields are in the form
+        self.assertContains(response, "New title")
+        self.assertContains(response, "New slug")
+        self.assertContains(response, "Copy subpages")
+        self.assertContains(response, "Publish copies")
+
+    def test_page_copy_bad_permissions(self):
+        # Remove privileges from user
+        self.user.is_superuser = False
+        self.user.user_permissions.add(
+            Permission.objects.get(content_type__app_label='wagtailadmin', codename='access_admin')
+        )
+        self.user.save()
+
+        # Get copy page
+        response = self.client.get(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )))
+
+        # Check that the user recieved a 403 response
+        self.assertEqual(response.status_code, 403)
+
+    def test_page_copy_post(self):
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello-world-2',
+            'copy_subpages': False,
+            'publish_copies': False,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Check that the user was redirected to the parents explore page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Get copy
+        page_copy = self.root_page.get_children().filter(slug='hello-world-2').first()
+
+        # Check that the copy exists
+        self.assertNotEqual(page_copy, None)
+
+        # Check that the copy is not live
+        self.assertFalse(page_copy.live)
+
+        # Check that the owner of the page is set correctly
+        self.assertEqual(page_copy.owner, self.user)
+
+        # Check that the children were not copied
+        self.assertEqual(page_copy.get_children().count(), 0)
+
+    def test_page_copy_post_copy_subpages(self):
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello-world-2',
+            'copy_subpages': True,
+            'publish_copies': False,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Check that the user was redirected to the parents explore page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Get copy
+        page_copy = self.root_page.get_children().filter(slug='hello-world-2').first()
+
+        # Check that the copy exists
+        self.assertNotEqual(page_copy, None)
+
+        # Check that the copy is not live
+        self.assertFalse(page_copy.live)
+
+        # Check that the owner of the page is set correctly
+        self.assertEqual(page_copy.owner, self.user)
+
+        # Check that the children were copied
+        self.assertEqual(page_copy.get_children().count(), 2)
+
+        # Check the the child pages
+        # Neither of them should be live
+        child_copy = page_copy.get_children().filter(slug='child-page').first()
+        self.assertNotEqual(child_copy, None)
+        self.assertFalse(child_copy.live)
+
+        unpublished_child_copy = page_copy.get_children().filter(slug='unpublished-child-page').first()
+        self.assertNotEqual(unpublished_child_copy, None)
+        self.assertFalse(unpublished_child_copy.live)
+
+    def test_page_copy_post_copy_subpages_publish_copies(self):
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello-world-2',
+            'copy_subpages': True,
+            'publish_copies': True,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Check that the user was redirected to the parents explore page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Get copy
+        page_copy = self.root_page.get_children().filter(slug='hello-world-2').first()
+
+        # Check that the copy exists
+        self.assertNotEqual(page_copy, None)
+
+        # Check that the copy is live
+        self.assertTrue(page_copy.live)
+
+        # Check that the owner of the page is set correctly
+        self.assertEqual(page_copy.owner, self.user)
+
+        # Check that the children were copied
+        self.assertEqual(page_copy.get_children().count(), 2)
+
+        # Check the the child pages
+        # The child_copy should be live but the unpublished_child_copy shouldn't
+        child_copy = page_copy.get_children().filter(slug='child-page').first()
+        self.assertNotEqual(child_copy, None)
+        self.assertTrue(child_copy.live)
+
+        unpublished_child_copy = page_copy.get_children().filter(slug='unpublished-child-page').first()
+        self.assertNotEqual(unpublished_child_copy, None)
+        self.assertFalse(unpublished_child_copy.live)
+
+    def test_page_copy_post_existing_slug(self):
+        # This tests the existing slug checking on page copy
+
+        # Attempt to copy the page but forget to change the slug
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello-world',
+            'copy_subpages': False,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Should not be redirected (as the save should fail)
+        self.assertEqual(response.status_code, 200)
+
+        # Check that a form error was raised
+        self.assertFormError(response, 'form', 'new_slug', "This slug is already in use")
+
+    def test_page_copy_post_invalid_slug(self):
+        # Attempt to copy the page but set an invalid slug string
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello world!',
+            'copy_subpages': False,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Should not be redirected (as the save should fail)
+        self.assertEqual(response.status_code, 200)
+
+        # Check that a form error was raised
+        self.assertFormError(response, 'form', 'new_slug', "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.")
+
+    def test_page_copy_no_publish_permission(self):
+        # Turn user into an editor who can add pages but not publish them
+        self.user.is_superuser = False
+        self.user.groups.add(
+            Group.objects.get(name="Editors"),
+        )
+        self.user.save()
+
+        # Get copy page
+        response = self.client.get(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )))
+
+        # The user should have access to the copy page
+        self.assertEqual(response.status_code, 200)
+        self.assertTemplateUsed(response, 'wagtailadmin/pages/copy.html')
+
+        # Make sure the "publish copies" field is hidden
+        self.assertNotContains(response, "Publish copies")
+
+    def test_page_copy_no_publish_permission_post_copy_subpages_publish_copies(self):
+        # This tests that unprivileged users cannot publish copied pages even if they hack their browser
+
+        # Turn user into an editor who can add pages but not publish them
+        self.user.is_superuser = False
+        self.user.groups.add(
+            Group.objects.get(name="Editors"),
+        )
+        self.user.save()
+
+        # Post
+        post_data = {
+            'new_title': "Hello world 2",
+            'new_slug': 'hello-world-2',
+            'copy_subpages': True,
+            'publish_copies': True,
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_copy', args=(self.test_page.id, )), post_data)
+
+        # Check that the user was redirected to the parents explore page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Get copy
+        page_copy = self.root_page.get_children().filter(slug='hello-world-2').first()
+
+        # Check that the copy exists
+        self.assertNotEqual(page_copy, None)
+
+        # Check that the copy is not live
+        self.assertFalse(page_copy.live)
+
+        # Check that the owner of the page is set correctly
+        self.assertEqual(page_copy.owner, self.user)
+
+        # Check that the children were copied
+        self.assertEqual(page_copy.get_children().count(), 2)
+
+        # Check the the child pages
+        # Neither of them should be live
+        child_copy = page_copy.get_children().filter(slug='child-page').first()
+        self.assertNotEqual(child_copy, None)
+        self.assertFalse(child_copy.live)
+
+        unpublished_child_copy = page_copy.get_children().filter(slug='unpublished-child-page').first()
+        self.assertNotEqual(unpublished_child_copy, None)
+        self.assertFalse(unpublished_child_copy.live)
+
+
 class TestPageUnpublish(TestCase, WagtailTestUtils):
     def setUp(self):
         self.user = self.login()
@@ -954,6 +1263,14 @@ class TestPageUnpublish(TestCase, WagtailTestUtils):
         """
         This posts to the unpublish view and checks that the page was unpublished
         """
+        # Connect a mock signal handler to page_unpublished signal
+        signal_fired = [False]
+        signal_page = [None]
+        def page_unpublished_handler(sender, instance, **kwargs):
+            signal_fired[0] = True
+            signal_page[0] = instance
+        page_unpublished.connect(page_unpublished_handler)
+
         # Post to the unpublish page
         response = self.client.post(reverse('wagtailadmin_pages_unpublish', args=(self.page.id, )), {
             'foo': "Must post something or the view won't see this as a POST request",
@@ -965,10 +1282,15 @@ class TestPageUnpublish(TestCase, WagtailTestUtils):
         # Check that the page was unpublished
         self.assertFalse(SimplePage.objects.get(id=self.page.id).live)
 
+        # Check that the page_unpublished signal was fired
+        self.assertTrue(signal_fired[0])
+        self.assertEqual(signal_page[0], self.page)
+        self.assertEqual(signal_page[0], signal_page[0].specific)
+
 
 class TestApproveRejectModeration(TestCase, WagtailTestUtils):
     def setUp(self):
-        self.submitter = User.objects.create_superuser(
+        self.submitter = get_user_model().objects.create_superuser(
             username='submitter',
             email='submitter@email.com',
             password='password',
@@ -1221,6 +1543,7 @@ class TestNotificationPreferences(TestCase, WagtailTestUtils):
         self.user = self.login()
 
         # Create two moderator users for testing 'submitted' email
+        User = get_user_model()
         self.moderator = User.objects.create_superuser('moderator', 'moderator@email.com', 'password')
         self.moderator2 = User.objects.create_superuser('moderator2', 'moderator2@email.com', 'password')
 
@@ -1343,3 +1666,36 @@ class TestNotificationPreferences(TestCase, WagtailTestUtils):
 
         # No email to send
         self.assertEqual(len(mail.outbox), 0)
+
+
+class TestIssue197(TestCase, WagtailTestUtils):
+    def test_issue_197(self):
+        # Find root page
+        self.root_page = Page.objects.get(id=2)
+
+        # Create a tagged page with no tags
+        self.tagged_page = self.root_page.add_child(instance=TaggedPage(
+            title="Tagged page",
+            slug='tagged-page',
+            live=False,
+        ))
+
+        # Login
+        self.user = self.login()
+
+        # Add some tags and publish using edit view
+        post_data = {
+            'title': "Tagged page",
+            'slug':'tagged-page',
+            'tags': "hello, world",
+            'action-publish': "Publish",
+        }
+        response = self.client.post(reverse('wagtailadmin_pages_edit', args=(self.tagged_page.id, )), post_data)
+
+        # Should be redirected to explorer page
+        self.assertRedirects(response, reverse('wagtailadmin_explore', args=(self.root_page.id, )))
+
+        # Check that both tags are in the pages tag set
+        page = TaggedPage.objects.get(id=self.tagged_page.id)
+        self.assertIn('hello', page.tags.slugs())
+        self.assertIn('world', page.tags.slugs())
