@@ -1,9 +1,10 @@
 from django.test import TestCase
+from django.core.urlresolvers import reverse
+from django.core import mail
+
 from wagtail.tests.utils import WagtailTestUtils
 from wagtail.wagtailcore.models import Page
 from wagtail.wagtailadmin.tasks import send_email_task
-from django.core.urlresolvers import reverse
-from django.core import mail
 
 
 class TestHome(TestCase, WagtailTestUtils):
@@ -43,3 +44,17 @@ class TestSendEmailTask(TestCase):
         self.assertEqual(mail.outbox[0].subject, "Test subject")
         self.assertEqual(mail.outbox[0].body, "Test content")
         self.assertEqual(mail.outbox[0].to, ["nobody@email.com"])
+
+
+class TestExplorerNavView(TestCase, WagtailTestUtils):
+    def setUp(self):
+        self.homepage = Page.objects.get(id=2).specific
+        self.login()
+
+    def test_explorer_nav_view(self):
+        response = self.client.get(reverse('wagtailadmin_explorer_nav'))
+
+        # Check response
+        self.assertEqual(response.status_code, 200)
+        self.assertTemplateUsed('wagtailadmin/shared/explorer_nav.html')
+        self.assertEqual(response.context['nodes'][0][0], self.homepage)
