@@ -10,21 +10,22 @@ from wagtail.wagtailadmin.menu import MenuItem
 from wagtail.wagtaildocs import admin_urls
 
 
+@hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
         url(r'^documents/', include(admin_urls)),
     ]
-hooks.register('register_admin_urls', register_admin_urls)
 
 
+@hooks.register('construct_main_menu')
 def construct_main_menu(request, menu_items):
     if request.user.has_perm('wagtaildocs.add_document'):
         menu_items.append(
             MenuItem(_('Documents'), urlresolvers.reverse('wagtaildocs_index'), classnames='icon icon-doc-full-inverse', order=400)
         )
-hooks.register('construct_main_menu', construct_main_menu)
 
 
+@hooks.register('insert_editor_js')
 def editor_js():
     js_files = [
         'wagtaildocs/js/hallo-plugins/hallo-wagtaildoclink.js',
@@ -42,4 +43,3 @@ def editor_js():
         """,
         urlresolvers.reverse('wagtaildocs_chooser')
     )
-hooks.register('insert_editor_js', editor_js)
