@@ -8,17 +8,17 @@ from wagtail.wagtailsearch.urls import admin as admin_urls
 from wagtail.wagtailadmin.menu import MenuItem
 
 
+@hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
         url(r'^search/', include(admin_urls)),
     ]
-hooks.register('register_admin_urls', register_admin_urls)
 
 
+@hooks.register('construct_main_menu')
 def construct_main_menu(request, menu_items):
     # TEMPORARY: Only show if the user is a superuser
     if request.user.is_superuser:
         menu_items.append(
             MenuItem(_('Editors picks'), urlresolvers.reverse('wagtailsearch_editorspicks_index'), classnames='icon icon-pick', order=900)
         )
-hooks.register('construct_main_menu', construct_main_menu)
