@@ -11,21 +11,22 @@ from wagtail.wagtailsnippets import urls
 from wagtail.wagtailsnippets.permissions import user_can_edit_snippets
 
 
+@hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
         url(r'^snippets/', include(urls)),
     ]
-hooks.register('register_admin_urls', register_admin_urls)
 
 
+@hooks.register('construct_main_menu')
 def construct_main_menu(request, menu_items):
     if user_can_edit_snippets(request.user):
         menu_items.append(
             MenuItem(_('Snippets'), urlresolvers.reverse('wagtailsnippets_index'), classnames='icon icon-snippet', order=500)
         )
-hooks.register('construct_main_menu', construct_main_menu)
 
 
+@hooks.register('insert_editor_js')
 def editor_js():
     return format_html("""
             <script src="{0}{1}"></script>
@@ -35,4 +36,3 @@ def editor_js():
         'wagtailsnippets/js/snippet-chooser.js',
         urlresolvers.reverse('wagtailsnippets_choose_generic')
     )
-hooks.register('insert_editor_js', editor_js)
