@@ -8,16 +8,16 @@ from wagtail.wagtailadmin.menu import MenuItem
 from wagtail.wagtailusers import urls
 
 
+@hooks.register('register_admin_urls')
 def register_admin_urls():
     return [
         url(r'^users/', include(urls)),
     ]
-hooks.register('register_admin_urls', register_admin_urls)
 
 
+@hooks.register('construct_main_menu')
 def construct_main_menu(request, menu_items):
     if request.user.has_module_perms('auth'):
         menu_items.append(
             MenuItem(_('Users'), urlresolvers.reverse('wagtailusers_index'), classnames='icon icon-user', order=600)
         )
-hooks.register('construct_main_menu', construct_main_menu)
